@@ -1,3 +1,5 @@
+#!/usr/bin/env python
+
 #
 # Copyright (C) 2005 Red Hat, Inc.
 #
@@ -20,31 +22,16 @@ def main (args):
     import locale
     import gettext
 
-    import gobject
-    from gobject.option import OptionParser, make_option
-
-    from gi.repository import Gtk
+    import gtk
+    import gtk.glade
 
+    from config import *
     import maindialog
-    import config
 
     locale.setlocale (locale.LC_ALL, "")
-    gettext.install (config.PACKAGE, config.LOCALEDIR)
+    gettext.install (PACKAGE, LOCALEDIR)
+    gtk.glade.bindtextdomain (PACKAGE, LOCALEDIR)
 
-    parser = OptionParser (
-            option_list = [
-		    # FIXME: remove this when we can get all the default
-		    # options
-                    make_option ("--version",
-                                 action="store_true",
-                                 dest="version",
-                                 help=config.VERSION),
-                ])
-    parser.parse_args (args)
+    dialog = maindialog.MenuEditorDialog ()
 
-    if parser.values.version:
-        # Translators: %s is the version number 
-        print _("Simple Menu Editor %s") % (config.VERSION)
-    else:
-        dialog = maindialog.MenuEditorDialog (args)
-        Gtk.main ()
+    gtk.main ()
